<!--巡检计划-->
<template>
  <div class="bbsl-common-page">
    <template v-if="componentName === 'table'">
      <div class="bbsl-table-search">
        <el-form v-model="queryParams" label-width="auto">
          <el-row :gutter="10">
            <el-col :span="5">
              <el-form-item label="车牌号">
                <el-input v-model="querys[0].value" clearable placeholder="请输入车牌号" />
              </el-form-item>
            </el-col>
            <el-col :span="4">
              <el-button icon="el-icon-search" type="primary" @click="handleSearch">
                搜索
              </el-button>
              <el-button icon="el-icon-refresh" @click="handleReset">
                重置
              </el-button>
            </el-col>
          </el-row>
        </el-form>
      </div>
      <div ref="contentPanel" class="bbsl-table-content">
        <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="tableData"
                  :header-cell-style="{ 'text-align': 'center' }"
                  :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                  row-key="id" size="mini"
                  @selection-change="handleSelectionChange" @sort-change="sortChange"
                  @row-dblclick="row => openPage('isShowAddModify', row)">
          <el-table-column align="center" reserve-selection type="selection" width="55"></el-table-column>
          <el-table-column align="center" label="序号" type="index" width="70">
          </el-table-column>
          <el-table-column align="center" label="车牌号" min-width="150" prop="code" show-overflow-tooltip />
          <el-table-column align="center" label="统计时间" min-width="150" prop="statisticTime" show-overflow-tooltip />

          <!--          <el-table-column :formatter="({ planType }) => dictionaryEscape(inspectionTypeOpt, planType + '')"-->
          <!--                           align="center" label="维护人员" min-width="100" prop="planType"-->
          <!--                           show-overflow-tooltip />-->
          <el-table-column align="center" label="车辆形式里程" min-width="100" prop="mileage"
                           show-overflow-tooltip />
          <el-table-column align="center" label="车辆状态" min-width="100" prop="status"
                           show-overflow-tooltip />
        </el-table>
        <el-pagination ref="paginationPanel" :current-page="queryParams.page" :page-size="queryParams.pageSize"
                       :page-sizes="[20, 30, 40, 50]"
                       :total="queryParams.total" align="right"
                       background
                       class="bbsl-pagination" layout="total, sizes, prev, pager, next, jumper"
                       @size-change="handleSizeChange" @current-change="handleCurrentChange"></el-pagination>
      </div>
    </template>


  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils'
import {dictionaryEscape} from '@/utils/dictionary'
import VehicleManage from '@/views/Manage/duty/api/vehicleManage'

export default {
  name: 'EquipmentInspectionPlan',
  components: {},
  // 日常巡检
  mixins: [TableMixin],
  data() {
    return {
      isShowAddModify: false,
      tableData: [],
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        'plan_Name_': '' // 巡检计划名称

      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code_',
          relation: 'AND',
          value: ''
        }],
      sorter: [],
      inspectionTypeOpt: dictUtils.getDictItemsFromCache('xjlx') || [],
      rowInfo: {},
      componentName: 'table',
      // 死数据
      fixedData: {
        statisticTime: '2023-06-15', // 统计时间
        mileage: '15,000公里',       // 车辆行驶里程
        status: '正常'               // 车辆状态
      }
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = [
        {operation: 'LIKE', property: 'plan_Name_'},
        {operation: 'EQUAL', property: 'planStartDate'},
        {operation: 'EQUAL', property: 'plan_End_Date_'},
        {operation: 'EQUAL', property: 'plan_Type_'}
      ]
      const {pageSize, page, ...item} = this.queryParams
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          /*
          * 取value值优先级：querys > queryParams
          * 方便后续有些参数默认值为一个固定的默认值，并且这个默认值不为空，也不会显示到页面上
          * */
          const value = i.value ?? item[i.property] ?? ''
          if (value === '') return []
          if (Array.isArray(value) && !value.length) return []
          return {group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
  },
  methods: {
    dictionaryEscape,
    // // 重置
    clearQuerys() {
      this.querys[0].value = ''
    },
    // handleReset() {
    //   this.querys[0].value = ''
    //   this.queryParams = this.$options.data().queryParams
    //   this.loadData()
    // },
    // 获取list
    // async loadData() {
    //   this.loading = true
    //   const {rows, total} = await tableData(this.computedQuery)
    //   this.tableData = rows
    //   this.queryParams.total = total
    //   this.loading = false
    // },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      // if (this.querys[1].value) {
      //   this.queryParam.querys.push(this.querys[1])
      // }
      VehicleManage.loadVehicle(this.queryParam, res => {
        this.total = res.total
        // this.tableData = res.rows
        // 将接口返回的数据与写死的数据合并
        this.tableData = res.rows.map(item => {
          return {
            ...item,
            statisticTime: this.fixedData.statisticTime,
            mileage: this.fixedData.mileage,
            status: this.fixedData.status
          }
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 顶部搜索
    // handleSearch() {
    //   this.loadData()
    // },
    //


    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = 1
      this.queryParams.page = page
      this.loadData()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.page = 1
      this.queryParams.pageSize = pageSize
      this.loadData()
    },

    // 排序切换
    sortChange({prop: property, order}) {
      let direction = ''
      switch (order) {
        case 'ascending':
          direction = 'ASC'
          break
        case 'descending':
          direction = 'DESC'
          break
      }
      this.sorter.forEach(i => {
        if (i.property !== property) return i.direction = ''
        i.direction = direction
      })
      this.loadData()
    },

    // 打开功能页面
    openPage(dialog, rowInfo = {}) {
      if (rowInfo.planStatus) {
        this.componentName = 'isShowDetailModify'
      } else {
        this.componentName = dialog
      }
      this.rowInfo = rowInfo // 保存点击行信息
    }

  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

::v-deep .el-link {
  span {
    font-size: 14PX;
  }
}
</style>
